@@ -10,6 +10,12 @@ import zoom.html as h
 import zoom.components as c
 
 
+def use_common_package(message):
+    zoom.requires('common_package_test')
+    return zoom.Component(
+        h.tag('div', message, id='common_package_test')
+    )
+
 
 def view():
 
@@ -46,6 +52,7 @@ def view():
         c.dropzone('/sample/components'),
         hr,
 
+        use_common_package('not updated yet')
     )
 
     return zoom.page(content, title='Components')
\ No newline at end of file
