@@ -71,8 +71,8 @@ class App(object):
     expects.
     """
 
-    def __init__(self):
-        self.menu = []
+    def __init__(self, menu=[]):
+        self.menu = menu
         self.request = None
 
     def static(self, *args, **kwargs):
@@ -173,6 +173,7 @@ class AppProxy(object):
         self.link = zoom.helpers.link_to(self.title, self.url)
         self.request = None
         self.packages = {}
+        self.common_packages = {}
 
         get = self.config.get
         self.visible = get('visible') not in zoom.utils.NEGATIVE
@@ -224,9 +225,12 @@ class AppProxy(object):
     def method(self):
         """Returns the app callable entry point"""
         if self._method is None:
+            split, join = os.path.split, os.path.join
             self.request.profiler.add('app loaded')
             self._method = getattr(load_module('app', self.filename), 'app')
-            self.packages = zoom.packages.load(os.path.join(self.path, 'packages.json'))
+            self.packages = zoom.packages.load(join(self.path, 'packages.json'))
+            apps_dir = split(self.path)[0]
+            self.common_packages = zoom.packages.load(join(apps_dir, 'packages.json'))
         return self._method
 
     @property
@@ -268,6 +272,7 @@ class AppProxy(object):
 
     def menu(self):
         """generate an app menu"""
+
         def by_name(name):
             """Returns a function that selects an item by name"""
             def selector(item):
@@ -278,13 +283,18 @@ class AppProxy(object):
         route = self.site.request.route
         logger = logging.getLogger(__name__)
         logger.debug('constructing menu')
+
         menu = getattr(self.method, 'menu', [])
+        if callable(menu):
+            menu = menu()  #pylint: disable=not-callable
+
         selected = (
             len(route) > 2 and route[0] == 'content' and route[2] or
             len(route) > 1 and route[1] or
             len(route) == 1 and route[0] != 'content' and 'index'
         )
         logger.debug('selected: %s', selected)
+
         result = as_links(menu, select=by_name(selected))
         return result
 
